import argparse
import pprint
import sys

from colorama import Fore, Style, init

import gaunit
from gaunit.models import Result
from gaunit.utils import (
    filter_keys,
    get_ga_requests_from_har,
    open_json,
    parse_ga_request,
)

from .__about__ import __version__


def check_har():
    parser = argparse.ArgumentParser()
    parser.add_argument("har_file", type=str, help="path to HAR file")
    parser.add_argument(
        "test_case",
        type=str,
        help="name of test case if more than one test in tracking plan",
    )
    parser.add_argument(
        "-t",
        "--tracking-plan",
        type=str,
        help="path to tracking plan",
        default="./tracking_plan.json",
    )
    parser.add_argument(
        "-a",
        "--all",
        help="print all expected events (missing and found)",
        action="store_true",
        dest="all",
    )
    parser.add_argument(
        "--version",
        help="print GAUnit version",
        action="version",
        version="GAUnit %s" % __version__,
    )

    args = parser.parse_args()

    # TODO : test_case should be optionnal if tracking plan has only one test_case
    # if args.tracking_plan:
    #  ..
    # else:
    #     if 1 test case in tracking plan
    #         r = gaunit.check_har(args.test_case, args.tracking_plan, har_path=args.har_file)
    #     # N test case
    #     else:
    #     # # error
    #     # print("error: more than one test case in tracking plan, please specify a '--test-case' parameter ")
    #     # pass

    tp = gaunit.TrackingPlan.from_json(args.tracking_plan)
    r = gaunit.check_har(args.test_case, tracking_plan=tp, har_path=args.har_file)

    r.print_result(display_ok=args.all)
    if False in r.checklist_expected_events:
        sys.exit(1)  # end with return code 1 if check failed
    # r.print_status_actual_events()


def extract_har():
    parser = argparse.ArgumentParser()
    parser.add_argument("har_file", type=str, help="path to HAR file")
    parser.add_argument(
        "-f",
        "--filter",
        help="list of specific events parameters to extract (other params are filtered out). Example: '--filter a b c'",
        nargs="+",
        dest="param_filter",
    )

    args = parser.parse_args()

    har = open_json(args.har_file)
    requests = get_ga_requests_from_har(har)
    events = []
    for r in requests:
        events.extend(parse_ga_request(r))

    if args.param_filter:
        param_filter = list(args.param_filter)
        events = [filter_keys(e, param_filter) for e in events]
    pprint.pprint(events)



"""
gaunit.api

This modules makes gaunit nicer to use
"""
from .models import Result, TestCase, TrackingPlan


def check_har(
    test_case_id: str, tracking_plan: TrackingPlan, har=None, har_path=None
) -> Result:
    """Performs checks of a har dict or HAR JSON file against a tracking plan

    Example:
        >>> expected_events = [{"t":"pageview","dt":"home"},...]
        >>> tracking_plan = gaunit.TrackingPlan.from_events("my_test_case", expected_events)
        >>> r = gaunit.check_har("my_test_case", tracking_plan, har=har) # from har dict
        >>> r.was_sucessful()
        True
        >>> r = gaunit.check_har("my_test_case", tracking_plan, har_path="har.json") # from HAR file
        >>> r.was_sucessful()
        True

    See also :
        :func:`gaunit.check_perf_log`

    Args:
        test_case_id (str): test case id (same id used to match with tracking plan)
        tracking_plan (TrackingPlan): tracking plan containing expected events for this
            test case. Defaults to None
        har (dict): actual har for this test case in dict format. Defaults to None
        har_path (str) : path to HAR file for this test case (standard HAR JSON). Defaults to None

    Note:
        one and one only argument must be given: ``har`` or ``har_path``

    Returns:
        :class:`gaunit.Result`: complete results of your test case.
    """
    tc = TestCase(test_case_id, tracking_plan=tracking_plan, har=har, har_path=har_path)
    return tc.result()


def check_perf_log(
    test_case_id: str, tracking_plan: TrackingPlan, perf_log: list
) -> Result:
    """Performs checks of a Performance log against a tracking plan

    For more info on Performance Log and how to get it, see
    https://chromedriver.chromium.org/logging/performance-log

    See also :
        :func:`gaunit.check_har`

    Example:
        >>> perf_log = driver.get_log("performance")  # selenium driver
        >>> r = gaunit.check_perf_log("my_test_case", tracking_plan, perf_log)
        >>> r.checklist_expected_events
        [True, True]
        >>> r.was_sucessful()
        True

    Args:
        test_case_id (str): test case id (same id used to match with tracking plan)
        tracking_plan (TrackingPlan): tracking plan containing expected events for this
            test case. Defaults to None
        perf_log (list): log entries from driver

    Returns:
        :class:`gaunit.Result`: complete results of your test case.
    """
    tc = TestCase(test_case_id, tracking_plan=tracking_plan, perf_log=perf_log)
    return tc.result()



"""
gaunit.utils

This module implements general methods used by gaunits.
"""
import json
import re
import sys
from typing import Tuple
from urllib.parse import parse_qs, unquote, urlparse


def open_json(json_path) -> dict:
    """convert JSON file into a dict"""

    with open(json_path, "r", encoding="utf8") as f:
        content = json.load(f)
    return content


def get_ga_requests_from_har(har: dict) -> list:
    """extract HAR requests from GA

    Args:
        har (dict): HAR from a test case

    Returns:
        list: list of requests from har (located in ``har["log"]["entries"]``)
    """
    # TODO change events to dict and add event type : [{"type":"GA4", "params":{} }]
    # get requests
    entries = har["log"]["entries"]
    requests = [e["request"] for e in entries]
    # extracting events from requests to Google Analytics domain only
    ga_requests = []
    for r in requests:
        if is_ga_url(r["url"]):
            ga_requests.append(r)
        pass
    return ga_requests


def parse_ga_request(request: dict) -> list:
    """extract event params from GA requests (POST and GET)

    Args:
        request (dict): a request extracted from har (located in ``har["log"]["entries"]``)

    Returns:
        list: list of GA events parameters
    """
    events = []
    r = request
    params_url = parse_ga_url(r["url"])
    if r["method"] == "GET":
        events = [params_url]
    if r["method"] == "POST":
        try:
            events = parse_postdata_events(r["postData"]["text"])
            # must add url params (shared by all events in postData)
            for e in events:
                e.update(params_url)
        except KeyError:
            # if no postData key, get url params anyway
            events = [params_url]
    return events


def parse_postdata_events(data: str) -> list:
    """extract events params from POST data

    Args:
        data (str): data string contained in GA POST request

    Returns:
        dict: all events found in POST data
    """
    # sample postdata: "en=page_view\r\nen=scroll&epn.percent_scrolled=90"
    # en=scroll
    # en=scroll&epn.percent_scrolled=90
    # ""

    events = []
    # events delimited by :
    for e in data.split("\r\n"):
        params = {}
        # params delimited by :
        for t in e.split("&"):
            if t:
                p, v = t.split("=")
                params.update({p: v})
            pass
        events.append(params)
    return format_events(events)


def get_ga_requests_from_browser_perf_log(log: list) -> list:
    """returns a list of HTTP requests urls found in log

    Args:
        log (list): log entries from ``driver.get_log("performance")``.

    Returns:
        list: list of urls
    """
    urls = []
    for entry in log:
        message = json.loads(entry["message"])["message"]
        if (
            "Network.response" in message["method"]  # not sure it is useful
            or "Network.request" in message["method"]
            or "Network.webSocket" in message["method"]  # same here
        ):
            try:
                url = message["params"]["request"]["url"]
                if is_ga_url(url):
                    urls.append(url)
            except:
                pass
    return urls


def load_dict_xor_json(d: dict, json_path: str) -> dict:
    """load  dict XOR json file

    one and one only argument must be given

    Args:
        d (dict): dict
        json_path (str) : path to HAR file (standard HAR Json)

    Returns:
        dict : d XOR dict with json file content

    Raises:
        ValueError: if zero or two arguments are given
    """
    # both arguments
    if d and json_path:
        raise ValueError(
            "too many arguments (dict and json_path). only one argument must be given"
        )
    # dict load
    elif d:
        return d
    # json load
    elif json_path:
        j = open_json(json_path)
        return j
    # no arguments
    else:
        raise ValueError("arguments given are both empty (dict or JSON file path)")


def parse_ga_url(url: str) -> dict:
    query = urlparse(url).query
    event_params = parse_qs(query)
    event_params = {
        f: event_params[f][0] for f in event_params
    }  # transform {f:[v]} to {f:v}
    return event_params


def is_ga_url(url: str) -> bool:
    # TODO check if rule is enough (no need of v=1 or v=2 params?)
    # TODO return GA event type (GA or GA4)
    r = False
    # GA
    if re.search(r"www\.google-analytics\.com\/(j\/|)collect.*", url):
        r = True
    # GA4
    if re.search(r"www\.google-analytics\.com\/g\/collect.*", url):
        r = True
    return r


def get_py_version() -> Tuple[int, int]:
    _ver = sys.version_info
    return (_ver[0], _ver[1])


def filter_keys(d: dict, key_filter: list) -> dict:
    d = {k: v for (k, v) in d.items() if k in key_filter}
    return d


def remove_empty_values(d: dict) -> dict:
    d = {k: v for (k, v) in d.items() if not v == ""}
    return d


def unquote_values(d: dict) -> dict:
    d = {k: unquote(str(v)) for (k, v) in d.items()}
    return d


def format_events(events: list) -> list:
    events = [unquote_values(e) for e in events]
    events = [remove_empty_values(e) for e in events]
    return events



"""
gaunit.models

This module implements main classes used by gaunit: :class:`TrackingPlan, 
:class:`TestCase` and :class:`Result`. 
"""
from __future__ import annotations

import json
import pprint
from typing import List, Tuple

from colorama import Fore, init
from gspread import Spreadsheet

from .utils import (
    format_events,
    get_ga_requests_from_browser_perf_log,
    get_ga_requests_from_har,
    get_py_version,
    load_dict_xor_json,
    open_json,
    parse_ga_request,
    parse_ga_url,
)


class TrackingPlan(object):
    def __init__(self):
        self.content = {}

    def get_expected_events(self, test_case_id: str) -> list:
        """get expected events for a given test case

        Args:
            test_case_id (str):  test case id
        """
        events = self.content[test_case_id]["events"]
        if events:
            return events
        else:
            raise Exception("test case not found in tracking plan: '%s'" % test_case_id)

    @classmethod
    def from_events(
        cls, test_case_id: str, expected_events: List[dict]
    ) -> TrackingPlan:
        """Creates an instance of :class:`TrackingPlan` from a list of expected events
        (only for one test case)

        Example :
            >>> from gaunit import TrackingPlan
            >>> expected_events = [{"t":"pageview","dt":"home"},...]
            >>> tracking_plan = TrackingPlan.from_events("my_test_case", expected_events)

        Args:
            test_case_id (str): [description]
            expected_events (list[Dict]): [description]

        Raises:
            KeyError: [description]
            AttributeError: [description]

        Returns:
            TrackingPlan: [description]
        """
        tp = TrackingPlan()
        tp.add_test_case(test_case_id, expected_events)
        return tp

    @classmethod
    def from_json(cls, path: str) -> TrackingPlan:
        """creates an instance of :class:`TrackingPlan` from a JSON file

        see Documentation for the JSON file format

        Example:
            >>> from gaunit import TrackingPlan
            >>> tracking_plan = TrackingPlan.from_json("tracking_plan.json")

        Args:
            path (str): path to JSON file representing the tracking plan

        Raises:
            KeyError: if format is not valid

        Returns:
            TrackingPlan: tracking plan to be used in a test case
        """
        tp = TrackingPlan()
        d = open_json(path)
        try:
            test_cases = d["test_cases"]
            for tc in test_cases:
                events = test_cases[tc]["events"]
                events = format_events(events)
                test_cases[tc]["events"] = events
            tp.content = test_cases
            return tp
        except KeyError:
            # TODO custom Exceptions
            raise KeyError("tracking plan is not valid (see Documentation) '%s'" % path)

    @classmethod
    def from_spreadsheet(cls, sheet: Spreadsheet) -> TrackingPlan:
        """creates an instance of :class:`TrackingPlan` from a Google Spreadsheet

        This method uses gspread to connect to Google Sheets to import test cases and
        expected events. See Documentation for the spreadsheet format.

        Examples:
            >>> import gspread
            >>> from gaunit import TrackingPlan
            >>> gc = gspread.service_account()  # authentication
            >>> sh = gc.open("Example spreadsheet")  # open spreadsheet
            >>> tp = TrackingPlan.from_spreadsheet(sh)  # import tracking plan

        Args:
            sheet (gspread.Spreadsheet): gspread instance of the spreadsheet to import

        Returns:
            TrackingPlan: tracking plan to be used in a test case.
        """
        tp = TrackingPlan()
        worksheets = sheet.worksheets()
        for w in worksheets:
            events = w.get_all_records()
            events = format_events(events)
            tp.add_test_case(w.title, events)
        return tp

    # @classmethod
    # def from_csv(cls, path: str) -> TrackingPlan:
    #     # TODO P1
    #     pass

    # @classmethod
    # def from_array(cls, array: List[list]) -> TrackingPlan:
    #     # First column has the name of the test_case
    #     # each row corresponds to an event
    #     # [[["test_case","dp","v"],["home_engie","home","1"],...]]
    #     # TODO
    #     pass

    def to_json(self, file: str):
        """Exports tracking plan into a JSON file

        Example :
            >>> from gaunit import TrackingPlan
            >>> expected_events = [{"t":"pageview","dt":"home"},...]
            >>> tracking_plan = gaunit.TrackingPlan.from_events("my_test_case", expected_events)
            >>> tracking_plan.to_json("tracking_plan.json")

        Args:
            file (str): target file
        """

        tracking_plan = {"test_cases": self.content}
        with open(file, "w", encoding="utf8") as f:
            json.dump(tracking_plan, f)

    def add_test_case(self, test_case_id: str, expected_events: List[dict]):
        """add or update expected events for a given test case.

        Example:

            >>> from gaunit import TrackingPlan
            >>> expected_events = [{"t":"pageview","dt":"home"},...]
            >>> tracking_plan = TrackingPlan()
            >>> tracking_plan.add_test_case("my_test_case", expected_events)


        See also:
            :func:TrackingPlan.from_events()

        Args:
            test_case_id (str): id of the test case
            expected_events (List[dict]): list of expected events for the given test case

        Raises:
            AttributeError: if format of expected_events is not valid
        """
        try:
            expected_events = format_events(expected_events)
            d = {test_case_id: {"events": expected_events}}
            self.content.update(d)
        except AttributeError:
            raise AttributeError(
                "no proper format for expected events: %s" % expected_events
            )

    def update_test_case(self, test_case_id: str, expected_events: List[dict]):
        """Simple alias for :func:`add_test_case()`"""
        self.add_test_case(test_case_id, expected_events)


class TestCase(object):
    """User-defined class object representing a test case.

    Used to get results between runned test case and expected tracking plan.

    Note:
        one and one only argument must be given: ``har`` or ``har_path``

    Example :
        >>> from gaunit import TestCase
        >>> events = [{"t":"pageview","dt":"home"},...]
        tc = TestCase("my_test_case", expected_events=events)
        >>> r = tc.check_har(har=har)  # or tc.check_har(har_path=path) for a HAR file
        >>> r.checklist_expected_events
        [True, True]
        >>> r.was_sucessful()
        True

    Attributes:
        id (str): test case id (same id used to match with tracking plan)
        tracking_plan (TrackingPlan): tracking plan containing expected events for this
            test case. Defaults to None
        har (dict): actual har for this test case in dict format. Defaults to None
        har_path (str) : path to HAR file for this test case (standard HAR JSON).
            Defaults to None.
        perf_log (list) : browser performance log

        actual_events (list) : list of GA events params parsed from HAR or http log
            Each event is represented by a dict of params (same as `expected_events`).
            Example: ``[{"t":"pageview","dt":"home"},...]``
            note that TestCase.check() will compare ``expected_events`` and
            ``actual_events``, which makes sense!
    """

    def __init__(
        self,
        id: str,
        tracking_plan: TrackingPlan,
        har: dict = None,
        har_path: str = None,
        perf_log: list = None,
    ):
        # Default empty dicts/lists for dict/lists params.
        har = {} if har is None else har
        perf_log = [] if perf_log is None else perf_log
        self.id = id  # test case name
        try:
            self.expected_events = tracking_plan.get_expected_events(self.id)
        except AttributeError:
            raise AttributeError(
                "tracking plan argument is not valid: %s" % tracking_plan
            )
        self.actual_events = []

        self.har = {}  # for debug, will be killed soon
        # self.page_flow = [] # will store urls from pages TODO
        # self.page_flow_ids = [] # will store har ids for pages
        if har or har_path:
            self.load_har(har, har_path)

        if perf_log:
            self.load_perf_log(perf_log)

    def load_har(self, har=None, har_path=None):
        """extracts and stores analytics hits from a har

        updates attributes `actual_events` (wip: page_flow).
        Takes one and one only argument : dict or path to a json file

        Args:
            har (dict, optional): [description]. Defaults to None.
            har_path (str, optional): [description]. Defaults to None.

        Raises:
            ValueError: if zero or two arguments are given.
        """

        har = load_dict_xor_json(har, har_path)
        # extract GA events
        requests = get_ga_requests_from_har(har)
        events = []
        for r in requests:
            events.extend(parse_ga_request(r))

        self.har = har  # TDO remove attribute
        self.actual_events = events

        # # extract pages (urls and har ids)
        # page_flow = get_pages_from_har(har)
        # page_flow_ids = get_pages_ids_from_har(har)

    def load_perf_log(self, perf_log: list):
        """extracts and stores analytics events from Performance Log

        For more info on Performance Log, see https://chromedriver.chromium.org/logging/performance-log

        Args:
            perf_log (list): log entries from ``driver.get_log("performance")``

        See also :
            :func:`TestCase.load_har`
        """
        # TODO GA4 check that there are no POST methods, otherwise throw an error or warning
        urls = get_ga_requests_from_browser_perf_log(perf_log)
        events = [parse_ga_url(url) for url in urls]

        self.actual_events = events

    def check(self, ordered=True) -> Tuple[list, list]:
        # TODO make private?
        """compares hits from tracking plan and from log and returns 2 checklists

        Args:
            ordered (bool, optional): True if we want hits to respect tracking plan
                order (default behavior)

        Raises:
            Exception: if something's missing (tracking plan, test case log entries or
                analytics events)

        Returns:
            Tuple[list, list]: 2 checklists:
                First checklist tells which event in tracking plan is missing
                Second checklist tells which analytics event from test case corresponds
                to an expected event
        """

        # check if everything needed is defined
        message = "tried to check tracking but something is missing: %s"
        missing = []
        if not self.expected_events:
            missing.append("tracking plan")
        if missing:
            raise Exception(message % ", ".join(missing))
        if not self.actual_events:
            raise Exception("no actual analytics event found in log")

        # start checking
        expected = self.expected_events
        actual = self.actual_events
        chklst_expected = []
        chklst_actual = [False] * len(actual)
        pos = 0  # position of last checked hit
        for t in expected:
            check = False
            for index, hit in enumerate(actual[pos:]):
                if t.items() <= hit.items():
                    # expected event is present : all params are there
                    check = True
                    chklst_actual[pos + index] = True
                    if ordered:
                        pos += index  # if we want hits to respect tracking plan order (default)
                    break
                # expected event is not here
            chklst_expected.append(check)

        return chklst_expected, chklst_actual

    def result(self):
        """performs tracking checks and return a Result class object"""

        expected, actual = self.check()
        r = Result(self, expected, actual)
        return r


class Result(object):
    """Let you store, get or print results from a test case in various forms

    Usually, Result will be returned by :class:`TestCase` or main API methods.

    See also :
        :func:`TestCase.result()`, :func:`gaunit.check_har()`

    Attributes:
        expected_events (list): events from tracking plan
        actual_events (list): events found during test run
        checklist_expected_events (list):  checklist of events from tracking plan which
        are missing (False if missing)
        checklist_actual_events (list): checklist of events found in log which corresponds
                to an expected event
    """

    def __init__(
        self, test_case: TestCase, checklist_expected: list, checklist_actual: list
    ):
        self.expected_events = test_case.expected_events
        self.actual_events = test_case.actual_events
        self.checklist_expected_events = checklist_expected
        self.checklist_actual_events = checklist_actual
        # self.comparison = None

    # TODO method to return merged results : comparison of both tracker and hits list

    def was_successful(self) -> bool:
        """returns the result of test case

        Returns:
            bool: True if test case was successful
        """
        return all(self.checklist_expected_events)

    def get_status_expected_events(self) -> list:
        """Returns expected event and their status

        Returns:
            list: list of expected events and their status (``True`` if found in actual events))

        Example:
            >>> from gaunit import TestCase
            >>> r = gaunit.check_har("my_test_case", tracking_plan, har=har)
            >>> r.get_status_expected_events()
            [{'event':{'t':'pageview', 'dp': 'home'}, 'found': True},..]
        """

        events = self.expected_events
        chcklst = self.checklist_expected_events

        return [{"event": h, "found": c} for (h, c) in zip(events, chcklst)]

    def get_status_actual_events(self) -> list:
        """Returns actual events and which ones were expected in tracking plan

        Returns:
            list: list of actual hits

        Example:
            >>> from gaunit import TestCase
            >>> r = gaunit.check_har("my_test_case", "tracking_plan.json", har=har)
            >>> r.get_status_actual_events()
            [{'event:{'t':'pageview', 'dp': 'home'}, 'expected': True}
        """

        events = self.actual_events
        chcklst = self.checklist_actual_events

        return [{"event": h, "expected": c} for (h, c) in zip(events, chcklst)]

    def print_result(self, display_ok=False):
        self._print_expected_events(all=display_ok)
        self._print_summary()

    def _print_expected_events(self, all=False):
        """pretty print list of events from tracking plan

        says which tracker was found in test case  ("OK" or "missing"), used in CLI

        Args:
            all (bool, optional): if False, print only missing events if True, print all.
                Defaults to False.
        """
        expected = self.expected_events
        chcklst = self.checklist_expected_events
        init(autoreset=True)  # colorama

        print("events in tracking plan: %s" % len(expected))
        args = (
            {"sort_dicts": False} if get_py_version() >= (3, 8) else {}
        )  # preserve dict params order when printing (only for Python>=3.8)
        for (event, check) in zip(expected, chcklst):
            if not check:
                print(80 * "=")
                pprint.pprint(event, **args)  # pylint: disable=E1123
                print(67 * " ", " ... " + Fore.RED + "missing")
            elif check and all:
                print(80 * "=")
                pprint.pprint(event, **args)  # pylint: disable=E1123
                print(72 * " ", " ... " + Fore.GREEN + "OK")
            else:
                pass

    def _print_summary(self):
        """print a result summary

        Example:
            output:

            | GA events found: total:4 / ok:3 / missing:0
            | ✔ OK: all expected events found

            or

            | GA events found: total:11 / ok:1 / missing:2
            | ❌ FAILED: events missing
            ""

        """
        expected = self.expected_events
        actual = self.actual_events
        chcklst = self.checklist_expected_events
        total_found, expected_found = len(actual), len([c for c in chcklst if c])
        missing = len(expected) - expected_found

        print(80 * "-")
        if total_found == 0:
            print("no GA events found")
        else:
            print(
                "GA events found: total:%s / ok:%s / missing:%s"
                % (total_found, expected_found, missing)
            )
        if False in chcklst:
            print("\N{Cross Mark} FAILED: events missing")
        else:
            print("\N{Heavy Check Mark} OK: all expected events found")

    def print_actual_events(self):
        """pretty print list of analytics hits from test case

        says which analytics hit was in tracking plan ("OK" or "skip"), used in CLI
        """
        events = self.actual_events
        chcklst = self.checklist_actual_events

        init(autoreset=True)  # colorama
        args = (
            {"sort_dicts": False} if get_py_version() >= (3, 8) else {}
        )  # preserve dict params order when printing (only for Python>=3.8)
        for (event, check) in zip(events, chcklst):
            print(80 * "=")
            pprint.pprint(event, **args)  # pylint: disable=E1123
            if check:
                print(72 * " ", " ... " + Fore.GREEN + "OK")
            else:
                print(70 * " ", " ... skip")



import io
import os

import setuptools

HERE = os.path.abspath(os.path.dirname(__file__))

ABOUT = {}
with io.open(os.path.join(HERE, "gaunit", "__about__.py"), "r", encoding="utf-8") as f:
    exec(f.read(), ABOUT)
with io.open("README.md", "r", encoding="utf8") as f:
    long_description = f.read()


setuptools.setup(
    name="gaunit",
    version=ABOUT["__version__"],
    author="Vincent Cabanis",
    author_email="touch@cabanis.fr",
    description="Testing Google Analytics implementations within CI pipelines",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/VinceCabs/GAUnit",
    packages=["gaunit"],
    entry_points={
        "console_scripts": [
            "gaunit=gaunit.cli:check_har",
            "gaextract=gaunit.cli:extract_har",
        ]
    },
    license="MIT",
    python_requires=">=3.7",
    install_requires=["colorama==0.4.4", "gspread==3.6.0"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Testing",
    ],
)
